import click

from swc.swc_processor import SwcProcessor

__version__ = '0.0.1'

CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])

processor = SwcProcessor()


@click.group(context_settings=CONTEXT_SETTINGS)
@click.version_option(__version__)
def cli():
    """stopwatch command"""


@cli.command()
def start():
    processor.start()



from datetime import datetime


class SwcProcessor:
    def __init__(self):
        pass

    def start(self):
        start = datetime.now()
        while True:
            now = datetime.now()
            print("\r" + str(now - start), end="")



import setuptools

from src.swc import swc

setuptools.setup(
    name="sw-cmd",
    version=swc.__version__,
    include_package_data=True,
    package_dir={"": "src"},
    packages=setuptools.find_namespace_packages(where="src", include=["*"]),
    python_requires=">=3.8",
    install_requires=[
        "click",
    ],
    entry_points="""
        [console_scripts]
        swc=swc.swc:cli
    """,
)
